@@ -41,9 +41,9 @@ TaskGeneratorMoons = R6Class("TaskGeneratorMoons",
     #'   Point char. Passed to [plot()].
     #' @param ... (any)\cr
     #'   Additional arguments passed to [plot()].
-    plot = function(n = 200, pch = 19L, ...) {
+    plot = function(n = 200L, pch = 19L, ...) {
       tab = private$.generate_obj(n)
-      plot(tab$x1, tab$x2, data = tab, pch = pch, col = tab$y, ...)
+      plot(tab$x1, tab$x2, pch = pch, col = tab$y)
     }
   ),
 
