@@ -57,7 +57,11 @@ mlr_tasks = R6Class("DictionaryTask",
 #' @export
 as.data.table.DictionaryTask = function(x, ...) {
   setkeyv(map_dtr(x$keys(), function(key) {
-    t = x$get(key)
+    t = tryCatch(x$get(key),
+      missingDefaultError = function(e) NULL)
+    if (is.null(t))
+      return(list(key = key))
+
     feats = translate_types(t$feature_types$type)
     insert_named(list(
       key = key,
@@ -65,5 +69,5 @@ as.data.table.DictionaryTask = function(x, ...) {
       nrow = t$nrow,
       ncol = t$ncol
     ), table(feats))
-  }), "key")[]
+  }, .fill = TRUE), "key")[]
 }
