@@ -464,9 +464,11 @@ expect_resample_result = function(rr, allow_incomplete = FALSE) {
   checkmate::expect_numeric(y[[m$id]], lower = m$range[1], upper = m$range[2], any.missing = FALSE, label = sprintf("measure %s", m$id))
   checkmate::expect_number(aggr[[m$id]], lower = m$range[1L], upper = m$range[2L], label = sprintf("measure %s", m$id))
 
-  lapply(rr$data$prediction, checkmate::expect_list, types = "Prediction", names = "unique")
+  checkmate::expect_list(
+    unlist(rr$data$prediction, recursive = FALSE), types = "PredictionData", len = expected_iters
+  )
+  checkmate::expect_list(rr$predictions(), types = "Prediction", len = expected_iters)
   expect_prediction(rr$prediction())
-  checkmate::expect_list(rr$predictions(), "Prediction")
 }
 
 expect_benchmark_result = function(bmr) {
@@ -474,7 +476,7 @@ expect_benchmark_result = function(bmr) {
   testthat::expect_output(print(bmr), "BenchmarkResult")
 
   checkmate::expect_data_table(bmr$data, min.cols = length(mlr3::mlr_reflections$rr_names) + 1L)
-  checkmate::expect_names(names(bmr$data), must.include = c(mlr3::mlr_reflections$rr_names, "uhash"))
+  checkmate::expect_names(names(as.data.table(bmr)), must.include = c(mlr3::mlr_reflections$rr_names, "uhash"))
 
   tab = bmr$tasks
   checkmate::expect_data_table(tab, ncols = 3L)
@@ -482,6 +484,7 @@ expect_benchmark_result = function(bmr) {
   expect_hash(tab$task_hash)
   expect_id(tab$task_id)
   checkmate::expect_list(tab$task, "Task")
+  expect_set_equal(bmr$tasks$task_hash, bmr$data$task)
 
   tab = bmr$learners
   checkmate::expect_data_table(tab, ncols = 3L)
@@ -489,6 +492,7 @@ expect_benchmark_result = function(bmr) {
   expect_hash(tab$learner_hash)
   expect_id(tab$learner_id)
   checkmate::expect_list(tab$learner, "Learner")
+  expect_set_equal(bmr$learners$learner_hash, bmr$data$learner)
 
   tab = bmr$resamplings
   checkmate::expect_data_table(tab, ncols = 3L)
@@ -496,6 +500,7 @@ expect_benchmark_result = function(bmr) {
   expect_hash(tab$resampling_hash)
   expect_id(tab$resampling_id)
   checkmate::expect_list(tab$resampling, "Resampling")
+  expect_set_equal(bmr$learners$learner_hash, bmr$data$learner)
 
   measures = mlr3::default_measures(bmr$task_type)
   tab = bmr$aggregate(measures, ids = TRUE)
@@ -516,9 +521,15 @@ expect_benchmark_result = function(bmr) {
 
   uhashes = bmr$uhashes
   expect_uhash(uhashes, len = data.table::uniqueN(bmr$data$uhash))
-  checkmate::expect_set_equal(uhashes, bmr$data$uhash)
+  testthat::expect_equal(uhashes, unique(bmr$data$uhash))
 
-  expect_equal(bmr$n_resample_results, length(bmr$uhashes))
+  expect_equal(bmr$n_resample_results, length(uhashes))
+
+  tab = bmr$resample_results
+  expect_data_table(tab, ncols = 3L, nrows = bmr$n_resample_results, any.missing = FALSE)
+  expect_character(tab$uhash)
+  expect_integer(tab$iters)
+  expect_list(tab$resample_result, types = "ResampleResult")
 
   checkmate::expect_choice(bmr$task_type, mlr3::mlr_reflections$task_types$type, null.ok = nrow(bmr$data) == 0L)
 }
