@@ -23,7 +23,7 @@ test_that("c", {
   lrn$predict_type = "se"
   rr = resample(task, lrn, rsmp("cv", folds = 3))
 
-  pred = do.call(c, map(rr$data$prediction, "test"))
+  pred = do.call(c, rr$predictions())
   expect_prediction(pred)
   expect_prediction_regr(pred)
 
@@ -45,7 +45,7 @@ test_that("c drops se (#250)", {
   lrn = lrn("regr.featureless")
   rr = resample(task, lrn, rsmp("cv", folds = 3))
 
-  pred = do.call(c, map(rr$data$prediction, "test"))
+  pred = do.call(c, rr$predictions())
   expect_null(pred$data$se)
   expect_false("se" %in% pred$predict_types)
   expect_true(allMissing(pred$se))
@@ -61,7 +61,7 @@ test_that("distr", {
     params = replicate(task$nrow, list(prob = runif(1), size = 10), FALSE)
   )
 
-  p = PredictionRegr$new(task, distr = distr)
+  p = PredictionRegr$new(row_ids = task$row_ids, truth = task$truth(), distr = distr)
   expect_output(print(p))
   expect_set_equal(p$predict_types, c("response", "se", "distr"))
   expect_numeric(p$response, len = task$nrow, any.missing = FALSE)
