@@ -5,6 +5,11 @@ test_that("autotest", {
   expect_learner(learner)
   result = run_autotest(learner)
   expect_true(result, info = result$error)
+
+  exclude = c("formula", "data", "weights", "subset", "na.action", "method", "model",
+    "x", "y", "parms", "control", "cost")
+  result = run_paramtest(learner, rpart::rpart, exclude)
+  expect_true(result, info = result$error)
 })
 
 test_that("variable importance", {
