@@ -14,12 +14,11 @@ test_that("stratification", {
   r = rsmp("holdout", ratio = .5)
   r$instantiate(task)
 
-  for (i in seq_len(r$iters)) {
-    expect_equal(task$data(r$train_set(i))[y == "a", .N], 45)
-    expect_equal(task$data(r$train_set(i))[y == "b", .N], 5)
-    expect_equal(task$data(r$test_set(i))[y == "a", .N], 45)
-    expect_equal(task$data(r$test_set(i))[y == "b", .N], 5)
-  }
+  i = 1L
+  expect_equal(task$data(r$train_set(i))[y == "a", .N], 45)
+  expect_equal(task$data(r$train_set(i))[y == "b", .N], 5)
+  expect_equal(task$data(r$test_set(i))[y == "a", .N], 45)
+  expect_equal(task$data(r$test_set(i))[y == "b", .N], 5)
 })
 
 test_that("grouping", {
